#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.7.3
visibility:           public
id:                   http-conduit-2.3.7.3-1gPhGmLd46pAQjucY9rkwt
key:                  http-conduit-2.3.7.3-1gPhGmLd46pAQjucY9rkwt
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/http-conduit
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  d07e7d2a75d05527a4f9e7053cd8f20a
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-8.10.2/site-local/http-conduit-2.3.7.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/http-conduit-2.3.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/http-conduit-2.3.7.3
hs-libraries:         HShttp-conduit-2.3.7.3-1gPhGmLd46pAQjucY9rkwt
depends:
    aeson-1.5.4.1-1IeGMr9U117LwJYrLRVKTY
    attoparsec-0.13.2.4-AOCP0w3yjps1ekkc06TeAr base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.4-4jvOBOzxV1hIVvrhitNicH
    conduit-extra-1.3.5-HfFATvBEagDKm7nPa1b9L3
    http-client-0.7.3-5jGDAnkoDshAJc6kikOv
    http-client-tls-0.3.5.3-JmjUjXMBBQrFxLND03KIyi
    http-types-0.12.3-DFZTOe1tP827vA146GCQqh mtl-2.2.2
    resourcet-1.2.4.2-IBltYvRLbCe9QRRPgabVbi transformers-0.5.6.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

